aboutsummaryrefslogtreecommitdiffstats
path: root/modules/desktop/default.nix
diff options
context:
space:
mode:
Diffstat (limited to 'modules/desktop/default.nix')
-rw-r--r--modules/desktop/default.nix18
1 files changed, 2 insertions, 16 deletions
diff --git a/modules/desktop/default.nix b/modules/desktop/default.nix
index eb2eea6..a2fdfc8 100644
--- a/modules/desktop/default.nix
+++ b/modules/desktop/default.nix
@@ -1,4 +1,4 @@
# Desktop - Desktop environment configuration (i3, GTK, polybar)
{
lib,
config,
@@ -6,10 +6,10 @@
}:
{
imports = [
- ./i3
./gtk
./polybar
./xdg
+ ./hyprland
];
options.desktop = {
@@ -18,19 +18,5 @@
config = lib.mkIf config.desktop.enable {
xdg.enable = true;
- xsession.enable = true;
-
- home.file.".xinitrc" = {
- text = ''
- #!/usr/bin/env sh
-
- [ -f ~/.Xresources ] && xrdb -merge ~/.Xresources
- [ -f ~/.profile ] && . ~/.profile
- [ -f ~/.xsession ] && . ~/.xsession
-
- exec ${config.xsession.windowManager.i3.package}/bin/i3
- '';
- executable = true;
- };
};
}
@@ -1,4 +1,4 @@
-# Desktop - Desktop environment configuration (i3, GTK, polybar)
+# Desktop - Desktop environment configuration (i3/Hyprland, GTK, polybar)
{
lib,